==> ejc-jlincome-api-3.0.0-20240510.080840-73-sources.jar: com/ejianc/business/jlincome/income/vo/SettleOtherVO.java <==
package com.ejianc.business.jlincome.income.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 收入管理-对甲结算-其他费用
 * 
 * @author generator
 * 
 */
public class SettleOtherVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long settleId; // 主表id
    private String otherName; // 费用名称
    private BigDecimal otherTaxMny; // 本期结算金额
    private BigDecimal otherMny; // 本期结算金额(无税)
    private BigDecimal otherTax; // 税额
    private BigDecimal otherTaxPrice; // 单价
    private BigDecimal otherPrice; // 单价（无税）
    private BigDecimal otherRate; // 税率
    private String otherMemo; // 备注
    

    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }
    public String getOtherName() {
        return otherName;
    }

    public void setOtherName(String otherName) {
        this.otherName = otherName;
    }
    public BigDecimal getOtherTaxMny() {
        return otherTaxMny;
    }

    public void setOtherTaxMny(BigDecimal otherTaxMny) {
        this.otherTaxMny = otherTaxMny;
    }
    public BigDecimal getOtherMny() {
        return otherMny;
    }

    public void setOtherMny(BigDecimal otherMny) {
        this.otherMny = otherMny;
    }
    public BigDecimal getOtherTax() {
        return otherTax;
    }

    public void setOtherTax(BigDecimal otherTax) {
        this.otherTax = otherTax;
    }
    public BigDecimal getOtherTaxPrice() {
        return otherTaxPrice;
    }

    public void setOtherTaxPrice(BigDecimal otherTaxPrice) {
        this.otherTaxPrice = otherTaxPrice;
    }
    public BigDecimal getOtherPrice() {
        return otherPrice;
    }

    public void setOtherPrice(BigDecimal otherPrice) {
        this.otherPrice = otherPrice;
    }
    public BigDecimal getOtherRate() {
        return otherRate;
    }

    public void setOtherRate(BigDecimal otherRate) {
        this.otherRate = otherRate;
    }
    public String getOtherMemo() {
        return otherMemo;
    }

    public void setOtherMemo(String otherMemo) {
        this.otherMemo = otherMemo;
    }
    
}

==> ejc-jlincome-api-3.0.0-20241115.002148-369-sources.jar: com/ejianc/business/jlincome/income/vo/SettleOtherVO.java <==
package com.ejianc.business.jlincome.income.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 收入管理-对甲结算-其他费用
 * 
 * @author generator
 * 
 */
public class SettleOtherVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long settleId; // 主表id
    private String otherName; // 费用名称
    private BigDecimal otherNum; // 本期结算量
    private BigDecimal otherTaxMny; // 本期结算金额
    private BigDecimal otherMny; // 本期结算金额(无税)
    private BigDecimal otherTax; // 税额
    private BigDecimal otherTaxPrice; // 单价
    private BigDecimal otherPrice; // 单价（无税）
    private BigDecimal otherRate; // 税率
    private String otherMemo; // 备注

    public BigDecimal getOtherNum() {
        return otherNum;
    }

    public void setOtherNum(BigDecimal otherNum) {
        this.otherNum = otherNum;
    }

    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }
    public String getOtherName() {
        return otherName;
    }

    public void setOtherName(String otherName) {
        this.otherName = otherName;
    }
    public BigDecimal getOtherTaxMny() {
        return otherTaxMny;
    }

    public void setOtherTaxMny(BigDecimal otherTaxMny) {
        this.otherTaxMny = otherTaxMny;
    }
    public BigDecimal getOtherMny() {
        return otherMny;
    }

    public void setOtherMny(BigDecimal otherMny) {
        this.otherMny = otherMny;
    }
    public BigDecimal getOtherTax() {
        return otherTax;
    }

    public void setOtherTax(BigDecimal otherTax) {
        this.otherTax = otherTax;
    }
    public BigDecimal getOtherTaxPrice() {
        return otherTaxPrice;
    }

    public void setOtherTaxPrice(BigDecimal otherTaxPrice) {
        this.otherTaxPrice = otherTaxPrice;
    }
    public BigDecimal getOtherPrice() {
        return otherPrice;
    }

    public void setOtherPrice(BigDecimal otherPrice) {
        this.otherPrice = otherPrice;
    }
    public BigDecimal getOtherRate() {
        return otherRate;
    }

    public void setOtherRate(BigDecimal otherRate) {
        this.otherRate = otherRate;
    }
    public String getOtherMemo() {
        return otherMemo;
    }

    public void setOtherMemo(String otherMemo) {
        this.otherMemo = otherMemo;
    }
    
}
